@@ -5,10 +5,10 @@ import sys
 from typing import Optional
 
 import click
-import click_log
 
 from .gitinfo import git_add, git_config_bool, git_edit
 from .scriv import Scriv
+from .util import scriv_command
 
 logger = logging.getLogger(__name__)
 
@@ -22,7 +22,7 @@ logger = logging.getLogger(__name__)
     default=None,
     help="Open the created file in your text editor.",
 )
-@click_log.simple_verbosity_option()
+@scriv_command
 def create(add: Optional[bool], edit: Optional[bool]) -> None:
     """
     Create a new changelog fragment.
