@@ -19,3 +19,14 @@ def without_module(using_module, missing_module_name: str):
 
     """
     return mock.patch.object(using_module, missing_module_name, None)
+
+
+def check_logs(caplog, expected):
+    """
+    Compare log records from caplog.
+
+    Only caplog records from a logger mentioned in expected are considered.
+    """
+    logger_names = set(r[0] for r in expected)
+    records = [r for r in caplog.record_tuples if r[0] in logger_names]
+    assert records == expected
