@@ -7,6 +7,8 @@ from unittest.mock import call
 
 import pytest
 
+from .helpers import check_logs
+
 CHANGELOG1 = """\
 Some text before
 
@@ -188,6 +190,17 @@ def test_bad_explicit_repo(cli_invoke, repo):
     assert str(result.exception) == f"Repo must be owner/reponame: {repo!r}"
 
 
+def test_check_links(cli_invoke, scenario1, mocker):
+    mock_check_links = mocker.patch("scriv.ghrel.check_markdown_links")
+    cli_invoke(["github-release", "--all", "--dry-run", "--check-links"])
+    assert mock_check_links.mock_calls == [
+        call("A good release\n"),
+        call("Nothing to say.\n"),
+        call("A beginning\n"),
+        call("Very first.\n"),
+    ]
+
+
 @pytest.fixture()
 def no_actions(mock_create_release, mock_update_release, responses):
     """Check that nothing really happened."""
@@ -201,51 +214,99 @@ def no_actions(mock_create_release, mock_update_release, responses):
 
 def test_default_dry_run(cli_invoke, scenario1, no_actions, caplog):
     cli_invoke(["github-release", "--dry-run"])
-    assert caplog.record_tuples == [
-        (
-            "scriv.changelog",
-            logging.INFO,
-            "Reading changelog CHANGELOG.rst",
-        ),
-        ("scriv.ghrel", logging.INFO, "Would create release v1.2.3"),
-        ("scriv.ghrel", logging.INFO, "Body:\nA good release\n"),
-    ]
+    check_logs(
+        caplog,
+        [
+            (
+                "scriv.changelog",
+                logging.INFO,
+                "Reading changelog CHANGELOG.rst",
+            ),
+            ("scriv.ghrel", logging.INFO, "Would create release v1.2.3"),
+        ],
+    )
 
 
 def test_dash_all_dry_run(cli_invoke, scenario1, no_actions, caplog):
     cli_invoke(["github-release", "--all", "--dry-run"])
-    assert caplog.record_tuples == [
-        (
-            "scriv.changelog",
-            logging.INFO,
-            "Reading changelog CHANGELOG.rst",
-        ),
-        ("scriv.ghrel", logging.INFO, "Would create release v1.2.3"),
-        ("scriv.ghrel", logging.INFO, "Body:\nA good release\n"),
-        (
-            "scriv.ghrel",
-            logging.WARNING,
-            "Entry 'Some fixes' has no version, skipping.",
-        ),
-        ("scriv.ghrel", logging.INFO, "Would update release v0.9a7"),
-        ("scriv.ghrel", logging.INFO, "Body:\nA beginning\n"),
-        (
-            "scriv.ghrel",
-            logging.WARNING,
-            "Version v0.1 has no tag. No release will be made.",
-        ),
-        ("scriv.ghrel", 20, "Would update release v0.0.1"),
-        ("scriv.ghrel", 20, "Body:\nVery first.\n"),
-    ]
+    check_logs(
+        caplog,
+        [
+            (
+                "scriv.changelog",
+                logging.INFO,
+                "Reading changelog CHANGELOG.rst",
+            ),
+            ("scriv.ghrel", logging.INFO, "Would create release v1.2.3"),
+            (
+                "scriv.ghrel",
+                logging.WARNING,
+                "Entry 'Some fixes' has no version, skipping.",
+            ),
+            ("scriv.ghrel", logging.INFO, "Would update release v0.9a7"),
+            (
+                "scriv.ghrel",
+                logging.WARNING,
+                "Version v0.1 has no tag. No release will be made.",
+            ),
+            ("scriv.ghrel", 20, "Would update release v0.0.1"),
+        ],
+    )
+
+
+def test_dash_all_dry_run_debug(cli_invoke, scenario1, no_actions, caplog):
+    cli_invoke(["github-release", "--all", "--dry-run", "--verbosity=debug"])
+    check_logs(
+        caplog,
+        [
+            (
+                "scriv.changelog",
+                logging.INFO,
+                "Reading changelog CHANGELOG.rst",
+            ),
+            (
+                "scriv.ghrel",
+                logging.DEBUG,
+                "Creating release, data = {'body': 'A good release\\n', 'name': 'v1.2.3', "
+                + "'tag_name': 'v1.2.3', 'draft': False, 'prerelease': False}",
+            ),
+            ("scriv.ghrel", logging.INFO, "Would create release v1.2.3"),
+            ("scriv.ghrel", logging.DEBUG, "Body:\nA good release\n"),
+            (
+                "scriv.ghrel",
+                logging.WARNING,
+                "Entry 'Some fixes' has no version, skipping.",
+            ),
+            (
+                "scriv.ghrel",
+                logging.DEBUG,
+                "Updating release v0.9a7, data = {'body': 'A beginning\\n', 'name': "
+                + "'v0.9a7', 'tag_name': 'v0.9a7', 'draft': False, 'prerelease': True}",
+            ),
+            ("scriv.ghrel", logging.INFO, "Would update release v0.9a7"),
+            ("scriv.ghrel", logging.DEBUG, "Body:\nA beginning\n"),
+            (
+                "scriv.ghrel",
+                logging.WARNING,
+                "Version v0.1 has no tag. No release will be made.",
+            ),
+            (
+                "scriv.ghrel",
+                logging.DEBUG,
+                "Updating release v0.0.1, data = {'body': 'Very first.\\n', 'name': "
+                + "'v0.0.1', 'tag_name': 'v0.0.1', 'draft': False, 'prerelease': False}",
+            ),
+            ("scriv.ghrel", logging.INFO, "Would update release v0.0.1"),
+            ("scriv.ghrel", logging.DEBUG, "Body:\nVery first.\n"),
+        ],
+    )
 
 
 def test_no_github_repo(cli_invoke, scenario1, fake_git):
     fake_git.remove_remote("origin")
     result = cli_invoke(["github-release"], expect_ok=False)
     assert result.exit_code == 1
-    assert result.output == (
-        "Reading changelog CHANGELOG.rst\n" + "Couldn't find a GitHub repo\n"
-    )
+    assert result.output == "Couldn't find a GitHub repo\n"
 
 
 def test_no_clear_github_repo(cli_invoke, scenario1, fake_git):
@@ -254,8 +315,7 @@ def test_no_clear_github_repo(cli_invoke, scenario1, fake_git):
     result = cli_invoke(["github-release"], expect_ok=False)
     assert result.exit_code == 1
     assert result.output == (
-        "Reading changelog CHANGELOG.rst\n"
-        + "More than one GitHub repo found: joe/project, psf/project\n"
+        "More than one GitHub repo found: joe/project, psf/project\n"
     )
 
 
